﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.SignalR;
using SignalRHubsAPIs.DataStorage;
using SignalRHubsAPIs.HubConfig;
using SignalRHubsAPIs.Models;
using SignalRHubsAPIs.TimerFeatures;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace SignalRHubsAPIs.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class ChartController : Controller
    {
        private readonly IHubContext<MessageHub> _hubContext;

        public ChartController(IHubContext<MessageHub> hubContext)
        {
            _hubContext = hubContext;
        }       

        [Route("NewMessage")]
        [HttpPost]
        public IActionResult NewMessage(Message msg)
        {
            _hubContext.Clients.All.SendAsync("OnetoOneMessageMessageReceived", msg);
            return Ok(new { Message = "Request Completed : Brodcast" });

        }
        [Route("OnetoOneMessage")]
        [HttpPost]
        public IActionResult OnetoOneMessage(Message msg)
        {
            foreach (string str in SubscriberHandler.SubscriberConnectedIds.Keys)
            {
                var ValuesList = SubscriberHandler.SubscriberConnectedIds[str];

                if (ValuesList[1].ToString() == msg.MSend)
                {
                    _hubContext.Clients.Client(str).SendAsync("OnetoOneMessageMessageReceived", msg);
                }
            }

            return Ok(new { Message = "Request Completed : One to One Message" });
        }
        [Route("JoinGroup")]
        [HttpPost]
        public IActionResult JoinGroup(Message msg)
        {
            foreach (string str in SubscriberHandler.SubscriberConnectedIds.Keys)
            {
                var ValuesList = SubscriberHandler.SubscriberConnectedIds[str];
                if (ValuesList[0].ToString() == msg.clientuniqueid)
                {
                    _hubContext.Groups.AddToGroupAsync(str, msg.Group);
                }
            }
            return Ok(new { Message = "Request Completed : Join Group" });
        }

        [Route("LeaveGroup")]
        [HttpPost]
        public IActionResult LeaveGroup(Message msg)
        {
            foreach (string str in SubscriberHandler.SubscriberConnectedIds.Keys)
            {
                var ValuesList = SubscriberHandler.SubscriberConnectedIds[str];
                if (ValuesList[0].ToString() == msg.clientuniqueid)
                {                    
                    _hubContext.Groups.RemoveFromGroupAsync(str, msg.Group);
                }
            }          
            return Ok(new { Message = "Request Completed : Leave Group" });
        }

        [Route("sendMessagetoGroup")]
        [HttpPost]
        public IActionResult sendMessagetoGroup(Message msg)
        {
            _hubContext.Clients.Group(msg.Group).SendAsync("OnetoOneMessageMessageReceived", msg);
            return Ok(new { Message = "Request Completed : Send Message to Group" });
        }


       


    }
}
